Crate clap_themes

Crate clap_themes 

clap_themes is a quick and easy way to add color and style to your clap-powered CLI!

Examples

use clap::Parser;

#[derive(Parser)]
#[clap(styles = clap_themes::CARGO)]
struct Cli {
    /// Here's some good help text!
    #[clap(short, long)]
    arg1: String,
}

Constants

CARGO
Colored output in the style of the cargo command.
CLAP_V3
Colored output in the style of clap v3, before they removed color.
DOOM_ONE
Colored output in the style of the “doom one” ViM theme.